MockSurrealEngine

Struct MockSurrealEngine 

pub struct MockSurrealEngine { /* private fields */ }
A mock SurrealDB engine that requires exact matching of requests

Implementations

Source

impl MockSurrealEngine

pub fn new() -> Self

Create a new mock engine

pub fn with_debug(self, debug: bool) -> Self

Enable debug logging of queries

pub fn with_exact_response( self, method: impl Into<String>, params: Value, response: Value, ) -> Self

Add an exact response for a specific method and parameters

pub fn with_method_response( self, method: impl Into<String>, response: Value, ) -> Self

Add a response for a method with empty parameters

pub fn with_query_response( self, query: impl Into<String>, response: Value, ) -> Self

Add a response for a query method with specific query string